@@ -1553,6 +1553,7 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 	POOL_SESSION_CONTEXT *session_context;
 	Node *node = NULL;
 	char *query = NULL;
+	bool got_estate = false;
 
 	/* Get session context */
 	session_context = pool_get_session_context();
@@ -1719,6 +1720,13 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 			{
 				state = kind;
 			}
+			/*
+			 * However, if the state is 'E', then frontend should had been
+			 * already reported an ERROR. So, to match with that, let be the
+			 * state to be returned to frontend.
+			 */
+			if (kind == 'E')
+				got_estate = true;
 		}
 	}
 
@@ -1730,6 +1738,8 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 		{
 			len = htonl(len);
 			pool_write(frontend, &len, sizeof(len));
+			if (got_estate)
+				state = 'E';
 			pool_write(frontend, &state, 1);
 		}
 		pool_flush(frontend);
